@@ -21,5 +21,5 @@ def run(room, y4m, lifetime=360):
     try:
         browser.close()
     except NoSuchWindowException as e:
-        print('Browser already closed.')
+        logging.warning('Browser already closed.')
     logger.info('Drone say goodbye ... Destroyed.')
